"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const apollo_cache_persist_1 = require("apollo-cache-persist");
const graphql_client_1 = require("vue-cli-plugin-apollo/graphql-client");
const pusher_js_1 = tslib_1.__importDefault(require("pusher-js"));
const CustomHeuristicFragmentMatcher_1 = tslib_1.__importDefault(require("./CustomHeuristicFragmentMatcher"));
const PusherLink_1 = tslib_1.__importDefault(require("./PusherLink"));
pusher_js_1.default.logToConsole = process.env.NODE_ENV !== 'production';
const AUTH_TOKEN = 'accessToken';
const httpEndpoint = process.env.VUE_APP_GRAPHQL_HTTP || 'http://127.0.0.1:3000/graphql';
const pusherLink = new PusherLink_1.default({
    pusher: new pusher_js_1.default(process.env.VUE_APP_PUSHER_KEY, {
        cluster: process.env.VUE_APP_PUSHER_CLUSTER,
        forceTLS: true,
        authEndpoint: `${process.env.VUE_APP_HTTP_ENDPOINT}/graphql/subscriptions/auth`,
        auth: {
            params: null,
            headers: {
                authorization: `Bearer ${localStorage.getItem(AUTH_TOKEN)}`,
            },
        },
    }),
});
const cache = new apollo_cache_inmemory_1.InMemoryCache({
    dataIdFromObject: result => (result.__typename && result.uuid ? `${result.__typename}:${result.uuid}` : apollo_cache_inmemory_1.defaultDataIdFromObject(result)),
    fragmentMatcher: new CustomHeuristicFragmentMatcher_1.default(),
});
apollo_cache_persist_1.persistCache({
    cache,
    storage: window.localStorage,
    debug: true,
});
const { apolloClient, wsClient } = graphql_client_1.createApolloClient({
    httpEndpoint,
    tokenName: AUTH_TOKEN,
    link: pusherLink,
    connectToDevTools: process.env.NODE_ENV !== 'production',
    cache,
});
exports.apolloClient = apolloClient;
exports.wsClient = wsClient;
//# sourceMappingURL=apolloClient.js.map