"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Model_1 = tslib_1.__importDefault(require("./models/Model"));
const Repository_1 = tslib_1.__importDefault(require("./repositories/Repository"));
const Registry_1 = tslib_1.__importDefault(require("./Registry"));
const Utils = tslib_1.__importStar(require("./utils"));
exports.Utils = Utils;
const graphql_1 = require("graphql");
const parser_1 = require("graphql/language/parser");
const utils_1 = require("./utils");
const registry = Registry_1.default.getInstance();
registry.set('Model', Model_1.default);
registry.set('Repository', Repository_1.default);
class VueOOPOptions {
    constructor() {
        this.rest = true;
        this.graphql = false;
        this.schema = null;
        this.schemaUrl = null;
        this.debug = false;
    }
}
exports.VueOOPOptions = VueOOPOptions;
async function VueOOP(Vue, options) {
    const config = {
        rest: true,
        graphql: false,
        schema: null,
        schemaUrl: null,
        debug: false,
        createProvider: null,
        ...options,
    };
    if (config.schemaUrl && config.debug) {
        config.schema = await utils_1.fetchIntrospectionSchema(config.schemaUrl)
            .then(graphql_1.buildClientSchema.bind(null))
            .then(graphql_1.printSchema.bind(null))
            .then(parser_1.parse.bind(null));
    }
    if (config.graphql) {
    }
    registry.set('Config', config);
    Vue.mixin({
        beforeCreate() {
            if (registry.has('Vue'))
                return;
            Object.defineProperty(Vue.prototype, '$registry', {
                get() {
                    if (!this.$_registry) {
                        this.$_registry = registry;
                    }
                    return this.$_registry;
                },
            });
            registry.set('Vue', this.$root);
        },
    });
}
exports.VueOOP = VueOOP;
exports.default = VueOOP;
var Registry_2 = require("./Registry");
exports.Registry = Registry_2.default;
var Repository_2 = require("./repositories/Repository");
exports.Repository = Repository_2.default;
var Model_2 = require("./models/Model");
exports.Model = Model_2.default;
var Collection_1 = require("./models/Collection");
exports.Collection = Collection_1.default;
var BaseException_1 = require("./models/Exceptions/BaseException");
exports.BaseException = BaseException_1.default;
var InvalidArgumentException_1 = require("./models/Exceptions/InvalidArgumentException");
exports.InvalidArgumentException = InvalidArgumentException_1.default;
var UnexpectedException_1 = require("./models/Exceptions/UnexpectedException");
exports.UnexpectedException = UnexpectedException_1.default;
var UnauthorizedException_1 = require("./models/Exceptions/UnauthorizedException");
exports.UnauthorizedException = UnauthorizedException_1.default;
var ValidationException_1 = require("./models/Exceptions/ValidationException");
exports.ValidationException = ValidationException_1.default;
//# sourceMappingURL=index.js.map